#homepage #slippy-map {
  display: none;
}

@media only screen and (min-width: 768px) {
  #homepage #slippy-map {
    display: block;
    width: 100%;
    height: 35em;
    position: relative;
  }
}

#examples span.zoom-in, #examples span.zoom-out {
  background-color: #fff;
  border-bottom: 1px solid #ccc;
  width: 23px;
  height: 23px;
  display: inline-block;
  text-align: center;
  text-decoration: none;
  color: black;
  box-shadow: 0 1px 7px rgba(0,0,0,0.65);
  -webkit-border-radius: 4px;
  border-radius: 4px;
}
#page-header {
  position:fixed;
  width: 100%;
  z-index: 10000;
  top:0px;
}
#page-header-title a:hover {
  color: #1f9e95;
  text-decoration: none;
}
#page-header,
.box-header {
  background-color: #084A49;
}
#page-header-title .title img {
  margin: 0 3px 0 0;
  vertical-align: bottom;
  height: 70px;
}
#page-header-title .header-buttons {
  float: right;
}
#page-header-title .fa-twitter {
  margin-right: 5px;
}
#page-header-title .mma-logo {
  margin: 5px 3px 0px 0px;
}
.box-header img {
  vertical-align: middle;
}
#page-footer {
  background-color: #084A49;
  border-top: 1px solid #084A49;
  color: #fff;
}
#page-footer ul.ul-icon-list {
  margin-bottom: 30px;
}

#how-to .content-container {
  padding: 2.5em 0;
}

#how-to h1.article-header {
  font-size: 3em;
  margin-bottom: .25em;
}

.chart .action-links a {
  text-decoration: none;
}

.data-drawer .tool-group {
  float: right;
}

.data-drawer h3.chart-title {
  margin-top: 6px;
}

.chart .action-links a {
  text-decoration: underline;
}

.tool-group a i {
  margin-left: 4px;
}

header.section-contents.table-explorer h1 a {
  float: none;
}

.hovercard .context,
.grid .context {
  display: none;
}
.grid .value {
  padding-right: 0em;
}

#about img {
  margin: 0px 0px 20px 20px;
}

@media only screen and (max-width: 768px) {
  #share-this-page {
    display: none;
  }

  #how-to h1.article-header {
    font-size: 2.5em;
  }

  #how-to .content-container {
    padding: 2em 0 1em;
  }

  #how-to .content-container:first-child {
    padding-top: 1em;
  }

  #landing-slippy-map {
    display: none;
    visibility: hidden;
  }

  #cover-map {
    margin: 0px;
  }

  #profile .content-container {
    margin: 0px;
  }

  #profile .explain {
    padding: 0 1.5em;
  }
}

@media only screen and (max-width: 360px) {
  #how-to h1.article-header {
    font-size: 2.2em;
  }
}

.profile-head2head-view #page-header-title {
  width: 100%;
  padding-left: 1.2em;
  padding-right: 1.2em;
}

.head2head-wrapper {
  background-color: #e0e4d4;
}

.profile-head2head-view #uvTab {
  display: none;
}

.profile-head2head-view iframe {
  float: left;
  width: 50%;
  height: 10000px;

  padding: 0px;
  margin: 0px;
  border: 0px;

  overflow-y: hidden;
}

.profile-head2head-view .frame-right {
  left: 50%;
  border-left: 5px solid #f7f8f3;
}

.profile-head2head-frame #page-header,
.profile-head2head-frame #page-footer,
.profile-head2head-frame #compare-place-picker,
.profile-head2head-frame #uvTab {
  display: none;
}

.banner {
  background: #1f9e95;
  text-align: center;
  color: #fff;
  padding: 40px !important;
  padding-bottom: 45px !important;
  margin-top: 89px;
}
.banner p {

}
#slippy-map {
  width: 100%;
}
.topics {
  background: #fff;
}

.topics .article-header {
  color: #084A49;
}
.topics i {
  font-size: 100px;
}

.topic-name {
  background: #084A49;
  color: #fff;
  text-transform: uppercase;
  height: auto;
  padding: 10px 14px;
  width: 60%;
  margin: 0 auto;
  margin-top: 10px;
  border-radius: 3px;
}
.topic {
  text-align: center;
  margin: 0px 0px 50px 0px;
}
.howitworks {
  background: #f4f4f4;
}

.partners {
  color: #084A49;
}
.partners img {
  height:70px;
}
.partners {
  background: #f0f0f0;
}
#page-footer .column-third {
  padding-left: 30px;
  border-right: 1px solid #f4f4f4;
  height: 183px;
}
#page-footer h1 {
  margin-bottom: 20px;
}
.search-section {
  margin-top: 21px;
  float: right;
}
.search-section.input-area {
  display: none;
  color: #084A49;
  height: 35px;
  border-radius: 0px !important;
  color: #084A49;
  font-size: 14px;
}
.div-area {
  background-color: #fff;
  padding: 5px 15px;
  width: 240px;
  height: 35px;
  border-radius: 0px;
  color: #084A49;
  font-size: 14px;
  line-height: 25px;
}
.div-area i {
  float: right;
  line-height: 22px;
}
#suggestdata {
  width: 820px;
  float: right;
}
#suggestdata .shell {
  border: 3px solid #084A49;
  padding:25px;
}
#suggestdata p {
  text-align: center;
  font-size: 18px;
  color: #084A49;
}
#suggestdata button {
  color: #fff;
  background-color: #084A49;
  font-size: 21px;
  padding: 10px 15px 12px;
  margin-bottom: 5px;
  border: none;
  font-family: "Lato", sans-serif;
}
#suggestdata button:hover {
  background-color: #1f9e95;
}
.profiles-container {
  float: right;
  padding-left: 10px;
}
#profile .content-container.wrapper {
  display: none;
}
.profile-head2head-frame .content-container.wrapper {
  display: none;
  width: 100%;
}
.snippet {
  text-align: center;
  color: #084A49;
  font-size: 17px;
  padding: 20px;
}
.filter-row-desc {
  color: #084A49;
  padding-left: 20px;
  font-size: 17px;
}
#compare-search-icon {
 position: absolute;
 top: 24px;
 left: 7px;
 font-size: 15px;
}
.g_HR {
  color: #fff !important;
  background-color: #084A49 !important;
  padding:5px 10px !important;
}
.g_C, .g_C a, .g_R0 {
  color: #fff !important;
  font-style: normal !important;
}
.g_BR {
  color: #084A49 !important;
}
h2.table-title {
  color: #084A49;
  font-weight: normal;
}
.header-for-columns {
  color: #084A49;
}

body.data-view {
  padding-top: 94px;
}
body.data-view .header-container {
  padding-top: 0;
}
#data-view-toggles a, #page-footer a {
  font-style: normal;
  color: #fff;
}
#data-view-toggles a {
  float: left;
  min-width: 100px;
}

#geography-add {
  height: 40px;
  color: #084A49;
  background-color: #f0f0f0;
  border: none;
  float: left;
  border-radius: 0px;
  line-height: 40px;
}
#geography-select {
  width: 100%;
}
.title {
  text-align: center;
}
#cover-profile .title {
  text-align: left;
  font-weight: 400
}
.topics-topic {
  text-align: center;
  min-height: 400px;
}
.topics-topic i {
  font-size: 80px;;
}
.topics-topic img {
  height: 95px;
}
.topics-topic ul {
  list-style: none;
}
.topic-desc, .categories {
  margin-top: 10px;
}
.topic:hover {
  color: #084A49 !important;
}
.filter-row-sub {
  display: none;
}
.filter-row {
  margin-bottom: 10px;
}
.banner-image {
  height: 400px;
}
.banner-image button {
  width: 360px;
  padding: 18px 18px 18px 36px;
  background-color: #1f9e95;
  text-align: left;
  text-transform: uppercase;
  border-radius: 5px;
  color: #fff;
  display: block;
  border: none;
  cursor: pointer;
  font-size: 18px;
  font-family: "Poppins", sans-serif;
  font-weight: 300;
  line-height: 100%;
}

.banner-image button i {
  float: right;
}
.current-loc {
 margin-top: 20px;
 padding: 15px 18px 15px 36px !important;
}
.mid blockquote{
  font-size: 24px;
  width: 50%;
  float: left;
  border: none;
}
.mid img{
  float: left;
}
.article-header-p {
  text-align: center;
}
.banner-image {
  background-position: 30% 100%;
}

/** Mobile view **/
@media screen and (max-width: 480px) {
  .country-select, .current-loc {
    padding: 10px;
    width: 80%;
    background-color: #1f9e95;
  }
  .country-select {
    margin-top: 140px;
  }
  .banner-image {
   background-position: 75% 43%;
   height: 280px;
 }
 .article-header {
  font-size: 24px !important;
}
.article-p {
  font-size: 14px;
}
#homepage {
  background-color: #124a47;
}
#page-header-title {
  margin: 0px !important;
}
#page-header .wrapper {
  padding: 1.4em 1.0em;
}
#menu {
  text-align: left;
  width: 200px;
  float: right;
  background: #124a47;
}
.tool-group a {
  border-bottom: 1px solid #999;
}
#slippy-map {
  display: none;
}
#cover-profile {
  margin-top: 0px !important;
}
#cover-profile article {
  border: 1px solid #124a47;
  width: 100%;
  padding: 15px;
  margin-top: 15px;
}
#profile .content-container {
  margin-left: 0px !important;
}
.filters {
  top: 0 !important;
  display: block;
  margin-left: 0px !important;
  position: inherit;
  height: auto;
  width: 27%;
  display: none;
}
#suggestdata .shell {
  width: 90%;
}
.callout.with-icon {
  width: 100% !important;
  float: right;
  text-align: center;
  padding-left: 0px !important;
}
#page-header-title .title img {
  height: 59px;
  margin-left: 30px;
}
.banner {
  display: none;
}
.banner.mobile {
  display: block;
}
.div-area, .input-area {
  width: 100%;
  border-radius: 10px;
}
.twitter-typeahead {
  width: 100%;
}
#menu {
  width: 100%;
  float: none;
}
#menu .search-section  {
  display: none;
}
#menu .tool-group {
  width: 100%;
  padding: 5px 0px;
  text-align: left;
  line-height: 20px;
  border-top: 1px solid #fff;
}
#menu .tool-group a {
  margin-left: 50px;
  border-bottom: none;
}
.filter-toggle-button  {
  display: block;
}


/** Button Dropdown **/
.dropbtn {
  margin-top: 100px;
}

.dropbtn:hover, .dropbtn:focus, .current-loc:focus, .current-loc:hover  {
  background-color: #124a47;
  border: none !important;
}

.dropdown {
  position: relative;
  display: inline-block;
}

.dropdown-content {
  display: none;
  position: absolute;
  background-color: #f9f9f9;
  width: 360px;
  overflow: auto;
  box-shadow: 0px 8px 16px 0px rgba(0,0,0,0.2);
}

.dropdown-content a {
  color: black;
  padding: 12px 16px;
  text-decoration: none;
  display: block;
}

.dropdown a:hover { background-color: #f1f1f1; }

.show { display: block; }

#countryDropdown a {
  color: #124a47;
  text-transform: uppercase;
  text-align: left;
}

.toggle-set li{
  min-width: 90px;
}
.toggle-set a:hover {
  background-color: #084A49;
  border-bottom: 1px solid #084A49;
}
#data-table {
  margin-top: 20px;
}
.showcase button {
  color: #fff;
  background-color: #084A49;
}
.showcase button:hover {
  color: #fff;
  background-color: #1f9e95;
}
.toggle-set a.active,
.toggle-set a:hover,
.toggle-set a.hovered {
  background-color: #1f9e95;
  color: #fff;
}
.filter-row .end {
  background-color: #084A49;
}
#cover-profile a {
  color: #084A49;
  text-decoration: none;
}
.chart-title {
  font-weight: 500 !important;
}
.footer-container  {
  padding-left: 20px;
}
.social-links {
  padding-left: 20px;
}
